@@ -182,7 +182,7 @@ sub master {
 # send packet via SocketPool
 # Args: ($self,$packet,$dst,$callback)
 #  $packet: Net::SIP::Packet
-#  $dst: where to send as hash with addr,port,family]
+#  $dst: where to send as hash with addr,port,family
 #  $callback: callback to call on definite successful delivery (TCP/TLS only)
 #    or on error
 ###########################################################################
@@ -258,7 +258,7 @@ sub sendto {
 	    ip_parts2string($dst));
 	my $clfd = INETSOCK(
 	    Proto => 'tcp',
-	    Reuse => 1,
+	    Reuse => 1, ReuseAddr => 1,
 	    LocalAddr => (ip_sockaddr2parts(getsockname($fo->{fd})))[0],
 	    Blocking => 0,
 	);
@@ -422,6 +422,7 @@ sub _handle_read_udp {
     invoke_callback($self->{cb},$pkt, {
 	%{ ip_sockaddr2parts($from) },
 	proto => 'udp',
+	socket => $fd,
     });
 }
 
@@ -540,6 +541,7 @@ sub _handle_read_tcp_co {
     invoke_callback($self->{cb},$pkt, {
 	%{ ip_sockaddr2parts($from) },
 	proto => $self->{tls} ? 'tls' : 'tcp',
+	socket => $fd,
     });
 
     # continue with processing any remaining data in the buffer
